@@ -80,7 +80,7 @@ class HostConnectionCache(dict):
         """
         Force a new connection to ``key`` host string.
         """
-        from fabric.state import env
+        from fabric.state import env, output
         user, host, port = normalize(key)
         key = normalize_to_string(key)
         sock = None
@@ -89,7 +89,9 @@ class HostConnectionCache(dict):
             gateway = normalize_to_string(env.gateway)
             # Ensure initial gateway connection
             if gateway not in self:
-                self[gateway] = connect(user, host, port)
+                if output.debug:
+                    print "Creating new gateway connection to %r" % gateway
+                self[gateway] = connect(*normalize(gateway))
             # Now we should have an open gw connection and can ask it for a
             # direct-tcpip channel to the real target. (Bypass our own
             # __getitem__ override to avoid hilarity.)
@@ -380,7 +382,7 @@ def connect(user, host, port, sock=None):
             # Otherwise, assume an auth exception, and prompt for new/better
             # password.
 
-            # The 'ssh' library doesn't handle prompting for locked private
+            # Paramiko doesn't handle prompting for locked private
             # keys (i.e.  keys with a passphrase and not loaded into an agent)
             # so we have to detect this and tweak our prompt slightly.
             # (Otherwise, however, the logic flow is the same, because
