@@ -688,8 +688,10 @@ def _prefix_env_vars(command):
     env_vars.update(env.shell_env)
 
     if env_vars:
-        exports = ' '.join('%s="%s"' % (k, _shell_escape(v))
-                           for k, v in env_vars.iteritems())
+        exports = ' '.join(
+            '%s="%s"' % (k, v if k == 'PATH' else _shell_escape(v))
+            for k, v in env_vars.iteritems()
+        )
         shell_env_str = 'export %s && ' % exports
     else:
         shell_env_str = ''
@@ -838,7 +840,8 @@ def open_shell(command=None):
 
     .. versionadded:: 1.0
     """
-    _execute(default_channel(), command, True, True, True)
+    _execute(channel=default_channel(), command=command, pty=True,
+        combine_stderr=True, invoke_shell=True)
 
 
 @contextmanager
@@ -875,8 +878,10 @@ def _run_command(command, shell=True, pty=True, combine_stderr=True,
             print("[%s] %s: %s" % (env.host_string, which, given_command))
 
         # Actual execution, stdin/stdout/stderr handling, and termination
-        result_stdout, result_stderr, status = _execute(default_channel(), wrapped_command,
-            pty, combine_stderr, stdout, stderr)
+        result_stdout, result_stderr, status = _execute(
+            channel=default_channel(), command=wrapped_command, pty=pty,
+            combine_stderr=combine_stderr, invoke_shell=False, stdout=stdout,
+            stderr=stderr)
 
         # Assemble output string
         out = _AttributeString(result_stdout)
@@ -964,7 +969,7 @@ def run(command, shell=True, pty=True, combine_stderr=None, quiet=False,
     standard error to the local standard out, while preserving it as its own
     distinct attribute on the return value (as per above.) Alternately, you
     could even provide your own stream objects or loggers, e.g. ``myout =
-    StringIO(); run("command, stdout=myout)``.
+    StringIO(); run("command", stdout=myout)``.
 
     Examples::
 
